@@ -15,6 +15,8 @@ from datetime import datetime
 from zipfile import ZipFile, ZIP_DEFLATED
 from struct import unpack
 
+from .compatibility import str_types
+
 # Package imports.
 from . import xmlwriter
 from xlsxwriter.worksheet import Worksheet
@@ -126,8 +128,12 @@ class Workbook(xmlwriter.XMLwriter):
 
     def __del__(self):
         """Close file in destructor if it hasn't been closed explicitly."""
-        if not self.fileclosed:
-            self.close()
+        try:
+            if not self.fileclosed:
+                self.close()
+        except:
+            raise Exception("Exception caught in workbook destructor. "
+                            "Explicit close() may be required for workbook.")
 
     def add_worksheet(self, name=None):
         """
@@ -636,11 +642,6 @@ class Workbook(xmlwriter.XMLwriter):
         for xf_format in (self.xf_formats + self.dxf_formats):
             num_format = xf_format.num_format
 
-            if sys.version_info[0] == 2:
-                str_types = basestring
-            else:
-                str_types = str
-
             # Check if num_format is an index to a built-in number format.
             if not isinstance(num_format, str_types):
                 xf_format.num_format_index = int(num_format)
